==> xray_audit-1.3.2.tar.gz: xray_audit/src/Services/PluginRepository.php <==
<?php

namespace Drupal\xray_audit\Services;

use Drupal\Core\Url;
use Drupal\xray_audit\Plugin\XrayAuditTaskPluginInterface;
use Drupal\xray_audit\Plugin\XrayAuditGroupPluginInterface;
use Drupal\xray_audit\Plugin\XrayAuditGroupPluginManager;
use Drupal\xray_audit\Plugin\XrayAuditTaskPluginManager;

/**
 * Retrieve data from entity about display modes.
 */
class PluginRepository implements PluginRepositoryInterface {

  /**
   * Group plugin manager.
   *
   * @var \Drupal\xray_audit\Plugin\XrayAuditGroupPluginManager
   */
  protected $groupPluginManager;

  /**
   * Task  plugin manager.
   *
   * @var \Drupal\xray_audit\Plugin\XrayAuditTaskPluginManager
   */
  protected $taskPluginManager;

  /**
   * Constructs the service.
   *
   * @param \Drupal\xray_audit\Plugin\XrayAuditGroupPluginManager $plugin_manager_xray_audit_group
   *   Group plugin manager.
   * @param \Drupal\xray_audit\Plugin\XrayAuditTaskPluginManager $plugin_manager_xray_audit_task
   *   Task  plugin manager.
   */
  public function __construct(XrayAuditGroupPluginManager $plugin_manager_xray_audit_group, XrayAuditTaskPluginManager $plugin_manager_xray_audit_task) {
    $this->groupPluginManager = $plugin_manager_xray_audit_group;
    $this->taskPluginManager = $plugin_manager_xray_audit_task;
  }

  /**
   * {@inheritdoc}
   */
  public function getGroupPageUrl(string $group_plugin_id) {
    return Url::fromRoute(
      'xray_audit.group_page',
      [self::PARAMETER_GROUP_PLUGIN => $group_plugin_id]
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getTaskPageOperationUrl(string $group_plugin_id, string $task_plugin_id, string $operation, array $options_query = NULL) {

    $query_paramenters = ['query' => []];

    if (!empty($options_query)) {
      $query_paramenters = ['query' => $options_query];
    }
    return Url::fromRoute(
      'xray_audit.task_page',
      [
        self::PARAMETER_GROUP_PLUGIN => $group_plugin_id,
        self::PARAMETER_TASK_OPERATION => $task_plugin_id . "-" . $operation,
      ],
      $query_paramenters);
  }

  /**
   * {@inheritdoc}
   */
  public function getBatchUrl(string $task_plugin, string $batch_process) {
    return Url::fromRoute(
      'xray_audit.batch_process',
      [
        self::PARAMETER_TASK_PLUGIN => $task_plugin,
        self::PARAMETER_BATCH_OPERATION => $batch_process,
      ]);
  }

  /**
   * {@inheritdoc}
   */
  public function explodeFromParameterTaskOperation(string $task_plugin_operation): ?array {
    $task_plugin_operation_array = explode('-', $task_plugin_operation);
    if (count($task_plugin_operation_array) !== 2) {
      return NULL;
    }
    return [
      self::PARAMETER_TASK_PLUGIN => $task_plugin_operation_array[0],
      self::PARAMETER_OPERATION => $task_plugin_operation_array[1],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getInstancePluginTask(string $task_plugin): ?XrayAuditTaskPluginInterface {
    try {
      /** @var \Drupal\xray_audit\Plugin\XrayAuditTaskPluginInterface $task_plugin */
      $task_plugin = $this->taskPluginManager->createInstance($task_plugin);
      if ($task_plugin instanceof XrayAuditTaskPluginInterface) {
        return $task_plugin;
      }
    }
    catch (\Exception $error) {
      $this->getLogger('xray-audit')->error($error->getMessage());
    }
    return NULL;

  }

  /**
   * {@inheritdoc}
   */
  public function getInstancePluginGroup(string $group_task): ?XrayAuditGroupPluginInterface {
    try {
      /** @var \Drupal\xray_audit\Plugin\XrayAuditGroupPluginInterface $$group_task */
      $group_task = $this->groupPluginManager->createInstance($group_task);
      if ($group_task instanceof XrayAuditGroupPluginInterface) {
        return $group_task;
      }
    }
    catch (\Exception $error) {
      $this->getLogger('xray-audit')->error($error->getMessage());
    }
    return NULL;

  }

  /**
   * {@inheritdoc}
   */
  public function getGroupPluginDefinitions(): array {
    return $this->groupPluginManager->getDefinitions();
  }

  /**
   * {@inheritdoc}
   */
  public function getTaskPluginDefinitions(): array {
    return $this->taskPluginManager->getDefinitions();
  }

}

==> xray_audit-1.5.1.tar.gz: xray_audit/src/Services/PluginRepository.php <==
<?php

namespace Drupal\xray_audit\Services;

use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Url;
use Drupal\xray_audit\Plugin\XrayAuditGroupPluginInterface;
use Drupal\xray_audit\Plugin\XrayAuditGroupPluginManager;
use Drupal\xray_audit\Plugin\XrayAuditTaskPluginInterface;
use Drupal\xray_audit\Plugin\XrayAuditTaskPluginManager;

/**
 * Retrieve data from entity about display modes.
 */
class PluginRepository implements PluginRepositoryInterface {

  /**
   * Group plugin manager.
   *
   * @var \Drupal\xray_audit\Plugin\XrayAuditGroupPluginManager
   */
  protected $groupPluginManager;

  /**
   * Task  plugin manager.
   *
   * @var \Drupal\xray_audit\Plugin\XrayAuditTaskPluginManager
   */
  protected $taskPluginManager;

  /**
   * Logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Constructs the service.
   *
   * @param \Drupal\xray_audit\Plugin\XrayAuditGroupPluginManager $plugin_manager_xray_audit_group
   *   Group plugin manager.
   * @param \Drupal\xray_audit\Plugin\XrayAuditTaskPluginManager $plugin_manager_xray_audit_task
   *   Task  plugin manager.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   Logger.
   */
  public function __construct(XrayAuditGroupPluginManager $plugin_manager_xray_audit_group, XrayAuditTaskPluginManager $plugin_manager_xray_audit_task, LoggerChannelFactoryInterface $logger_factory) {
    $this->groupPluginManager = $plugin_manager_xray_audit_group;
    $this->taskPluginManager = $plugin_manager_xray_audit_task;
    $this->logger = $logger_factory->get('xray_audit');
  }

  /**
   * {@inheritdoc}
   */
  public function getGroupPageUrl(string $group_plugin_id) {
    return Url::fromRoute(
      'xray_audit.group_page',
      [self::PARAMETER_GROUP_PLUGIN => $group_plugin_id]
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getTaskPageOperationUrl(string $group_plugin_id, string $task_plugin_id, string $operation, array $options_query = NULL) {

    $query_paramenters = ['query' => []];

    if (!empty($options_query)) {
      $query_paramenters = ['query' => $options_query];
    }
    return Url::fromRoute(
      'xray_audit.task_page',
      [
        self::PARAMETER_GROUP_PLUGIN => $group_plugin_id,
        self::PARAMETER_TASK_OPERATION => $task_plugin_id . "-" . $operation,
      ],
      $query_paramenters);
  }

  /**
   * {@inheritdoc}
   */
  public function getBatchUrl(string $task_plugin, string $batch_process) {
    return Url::fromRoute(
      'xray_audit.batch_process',
      [
        self::PARAMETER_TASK_PLUGIN => $task_plugin,
        self::PARAMETER_BATCH_OPERATION => $batch_process,
      ]);
  }

  /**
   * {@inheritdoc}
   */
  public function explodeFromParameterTaskOperation(string $task_plugin_operation): ?array {
    $task_plugin_operation_array = explode('-', $task_plugin_operation);
    if (count($task_plugin_operation_array) !== 2) {
      return NULL;
    }
    return [
      self::PARAMETER_TASK_PLUGIN => $task_plugin_operation_array[0],
      self::PARAMETER_OPERATION => $task_plugin_operation_array[1],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getInstancePluginTask(string $task_plugin): ?XrayAuditTaskPluginInterface {
    try {
      /** @var \Drupal\xray_audit\Plugin\XrayAuditTaskPluginInterface $task_plugin */
      $task_plugin = $this->taskPluginManager->createInstance($task_plugin);
      if ($task_plugin instanceof XrayAuditTaskPluginInterface) {
        return $task_plugin;
      }
    }
    catch (\Exception $error) {
      $this->logger->error($error->getMessage());
    }
    return NULL;

  }

  /**
   * {@inheritdoc}
   */
  public function getInstancePluginGroup(string $group_task): ?XrayAuditGroupPluginInterface {
    try {
      /** @var \Drupal\xray_audit\Plugin\XrayAuditGroupPluginInterface $$group_task */
      $group_task = $this->groupPluginManager->createInstance($group_task);
      if ($group_task instanceof XrayAuditGroupPluginInterface) {
        return $group_task;
      }
    }
    catch (\Exception $error) {
      $this->logger->error($error->getMessage());
    }
    return NULL;

  }

  /**
   * {@inheritdoc}
   */
  public function getGroupPluginDefinitions(): array {
    return $this->groupPluginManager->getDefinitions();
  }

  /**
   * {@inheritdoc}
   */
  public function getTaskPluginDefinitions(): array {
    return $this->taskPluginManager->getDefinitions();
  }

}
